==> zio-aws-chimesdkmeetings_2.13-5.17.195.3-sources.jar: zio/aws/chimesdkmeetings/model/TranscribeLanguageCode.scala <==
package zio.aws.chimesdkmeetings.model
import scala.jdk.CollectionConverters._
sealed trait TranscribeLanguageCode {
  def unwrap: software.amazon.awssdk.services.chimesdkmeetings.model.TranscribeLanguageCode
}
object TranscribeLanguageCode {
  def wrap(
      value: software.amazon.awssdk.services.chimesdkmeetings.model.TranscribeLanguageCode
  ): zio.aws.chimesdkmeetings.model.TranscribeLanguageCode = value match {
    case software.amazon.awssdk.services.chimesdkmeetings.model.TranscribeLanguageCode.UNKNOWN_TO_SDK_VERSION =>
      val r = unknownToSdkVersion
      r
    case software.amazon.awssdk.services.chimesdkmeetings.model.TranscribeLanguageCode.EN_US =>
      val r = `en-US`
      r
    case software.amazon.awssdk.services.chimesdkmeetings.model.TranscribeLanguageCode.EN_GB =>
      val r = `en-GB`
      r
    case software.amazon.awssdk.services.chimesdkmeetings.model.TranscribeLanguageCode.ES_US =>
      val r = `es-US`
      r
    case software.amazon.awssdk.services.chimesdkmeetings.model.TranscribeLanguageCode.FR_CA =>
      val r = `fr-CA`
      r
    case software.amazon.awssdk.services.chimesdkmeetings.model.TranscribeLanguageCode.FR_FR =>
      val r = `fr-FR`
      r
    case software.amazon.awssdk.services.chimesdkmeetings.model.TranscribeLanguageCode.EN_AU =>
      val r = `en-AU`
      r
    case software.amazon.awssdk.services.chimesdkmeetings.model.TranscribeLanguageCode.IT_IT =>
      val r = `it-IT`
      r
    case software.amazon.awssdk.services.chimesdkmeetings.model.TranscribeLanguageCode.DE_DE =>
      val r = `de-DE`
      r
    case software.amazon.awssdk.services.chimesdkmeetings.model.TranscribeLanguageCode.PT_BR =>
      val r = `pt-BR`
      r
    case software.amazon.awssdk.services.chimesdkmeetings.model.TranscribeLanguageCode.JA_JP =>
      val r = `ja-JP`
      r
    case software.amazon.awssdk.services.chimesdkmeetings.model.TranscribeLanguageCode.KO_KR =>
      val r = `ko-KR`
      r
    case software.amazon.awssdk.services.chimesdkmeetings.model.TranscribeLanguageCode.ZH_CN =>
      val r = `zh-CN`
      r
  }
  case object unknownToSdkVersion
      extends zio.aws.chimesdkmeetings.model.TranscribeLanguageCode {
    override def unwrap
        : software.amazon.awssdk.services.chimesdkmeetings.model.TranscribeLanguageCode =
      software.amazon.awssdk.services.chimesdkmeetings.model.TranscribeLanguageCode.UNKNOWN_TO_SDK_VERSION
  }
  case object `en-US`
      extends zio.aws.chimesdkmeetings.model.TranscribeLanguageCode {
    override def unwrap
        : software.amazon.awssdk.services.chimesdkmeetings.model.TranscribeLanguageCode =
      software.amazon.awssdk.services.chimesdkmeetings.model.TranscribeLanguageCode.EN_US
  }
  case object `en-GB`
      extends zio.aws.chimesdkmeetings.model.TranscribeLanguageCode {
    override def unwrap
        : software.amazon.awssdk.services.chimesdkmeetings.model.TranscribeLanguageCode =
      software.amazon.awssdk.services.chimesdkmeetings.model.TranscribeLanguageCode.EN_GB
  }
  case object `es-US`
      extends zio.aws.chimesdkmeetings.model.TranscribeLanguageCode {
    override def unwrap
        : software.amazon.awssdk.services.chimesdkmeetings.model.TranscribeLanguageCode =
      software.amazon.awssdk.services.chimesdkmeetings.model.TranscribeLanguageCode.ES_US
  }
  case object `fr-CA`
      extends zio.aws.chimesdkmeetings.model.TranscribeLanguageCode {
    override def unwrap
        : software.amazon.awssdk.services.chimesdkmeetings.model.TranscribeLanguageCode =
      software.amazon.awssdk.services.chimesdkmeetings.model.TranscribeLanguageCode.FR_CA
  }
  case object `fr-FR`
      extends zio.aws.chimesdkmeetings.model.TranscribeLanguageCode {
    override def unwrap
        : software.amazon.awssdk.services.chimesdkmeetings.model.TranscribeLanguageCode =
      software.amazon.awssdk.services.chimesdkmeetings.model.TranscribeLanguageCode.FR_FR
  }
  case object `en-AU`
      extends zio.aws.chimesdkmeetings.model.TranscribeLanguageCode {
    override def unwrap
        : software.amazon.awssdk.services.chimesdkmeetings.model.TranscribeLanguageCode =
      software.amazon.awssdk.services.chimesdkmeetings.model.TranscribeLanguageCode.EN_AU
  }
  case object `it-IT`
      extends zio.aws.chimesdkmeetings.model.TranscribeLanguageCode {
    override def unwrap
        : software.amazon.awssdk.services.chimesdkmeetings.model.TranscribeLanguageCode =
      software.amazon.awssdk.services.chimesdkmeetings.model.TranscribeLanguageCode.IT_IT
  }
  case object `de-DE`
      extends zio.aws.chimesdkmeetings.model.TranscribeLanguageCode {
    override def unwrap
        : software.amazon.awssdk.services.chimesdkmeetings.model.TranscribeLanguageCode =
      software.amazon.awssdk.services.chimesdkmeetings.model.TranscribeLanguageCode.DE_DE
  }
  case object `pt-BR`
      extends zio.aws.chimesdkmeetings.model.TranscribeLanguageCode {
    override def unwrap
        : software.amazon.awssdk.services.chimesdkmeetings.model.TranscribeLanguageCode =
      software.amazon.awssdk.services.chimesdkmeetings.model.TranscribeLanguageCode.PT_BR
  }
  case object `ja-JP`
      extends zio.aws.chimesdkmeetings.model.TranscribeLanguageCode {
    override def unwrap
        : software.amazon.awssdk.services.chimesdkmeetings.model.TranscribeLanguageCode =
      software.amazon.awssdk.services.chimesdkmeetings.model.TranscribeLanguageCode.JA_JP
  }
  case object `ko-KR`
      extends zio.aws.chimesdkmeetings.model.TranscribeLanguageCode {
    override def unwrap
        : software.amazon.awssdk.services.chimesdkmeetings.model.TranscribeLanguageCode =
      software.amazon.awssdk.services.chimesdkmeetings.model.TranscribeLanguageCode.KO_KR
  }
  case object `zh-CN`
      extends zio.aws.chimesdkmeetings.model.TranscribeLanguageCode {
    override def unwrap
        : software.amazon.awssdk.services.chimesdkmeetings.model.TranscribeLanguageCode =
      software.amazon.awssdk.services.chimesdkmeetings.model.TranscribeLanguageCode.ZH_CN
  }
}

==> zio-aws-chimesdkmeetings_2.13-7.21.15.5-sources.jar: zio/aws/chimesdkmeetings/model/TranscribeLanguageCode.scala <==
package zio.aws.chimesdkmeetings.model
import scala.jdk.CollectionConverters._
sealed trait TranscribeLanguageCode {
  def unwrap: software.amazon.awssdk.services.chimesdkmeetings.model.TranscribeLanguageCode
}
object TranscribeLanguageCode {
  def wrap(
      value: software.amazon.awssdk.services.chimesdkmeetings.model.TranscribeLanguageCode
  ): zio.aws.chimesdkmeetings.model.TranscribeLanguageCode = value match {
    case software.amazon.awssdk.services.chimesdkmeetings.model.TranscribeLanguageCode.UNKNOWN_TO_SDK_VERSION =>
      val r = unknownToSdkVersion
      r
    case software.amazon.awssdk.services.chimesdkmeetings.model.TranscribeLanguageCode.EN_US =>
      val r = `en-US`
      r
    case software.amazon.awssdk.services.chimesdkmeetings.model.TranscribeLanguageCode.EN_GB =>
      val r = `en-GB`
      r
    case software.amazon.awssdk.services.chimesdkmeetings.model.TranscribeLanguageCode.ES_US =>
      val r = `es-US`
      r
    case software.amazon.awssdk.services.chimesdkmeetings.model.TranscribeLanguageCode.FR_CA =>
      val r = `fr-CA`
      r
    case software.amazon.awssdk.services.chimesdkmeetings.model.TranscribeLanguageCode.FR_FR =>
      val r = `fr-FR`
      r
    case software.amazon.awssdk.services.chimesdkmeetings.model.TranscribeLanguageCode.EN_AU =>
      val r = `en-AU`
      r
    case software.amazon.awssdk.services.chimesdkmeetings.model.TranscribeLanguageCode.IT_IT =>
      val r = `it-IT`
      r
    case software.amazon.awssdk.services.chimesdkmeetings.model.TranscribeLanguageCode.DE_DE =>
      val r = `de-DE`
      r
    case software.amazon.awssdk.services.chimesdkmeetings.model.TranscribeLanguageCode.PT_BR =>
      val r = `pt-BR`
      r
    case software.amazon.awssdk.services.chimesdkmeetings.model.TranscribeLanguageCode.JA_JP =>
      val r = `ja-JP`
      r
    case software.amazon.awssdk.services.chimesdkmeetings.model.TranscribeLanguageCode.KO_KR =>
      val r = `ko-KR`
      r
    case software.amazon.awssdk.services.chimesdkmeetings.model.TranscribeLanguageCode.ZH_CN =>
      val r = `zh-CN`
      r
    case software.amazon.awssdk.services.chimesdkmeetings.model.TranscribeLanguageCode.TH_TH =>
      val r = `th-TH`
      r
    case software.amazon.awssdk.services.chimesdkmeetings.model.TranscribeLanguageCode.HI_IN =>
      val r = `hi-IN`
      r
  }
  case object unknownToSdkVersion
      extends zio.aws.chimesdkmeetings.model.TranscribeLanguageCode {
    override def unwrap
        : software.amazon.awssdk.services.chimesdkmeetings.model.TranscribeLanguageCode =
      software.amazon.awssdk.services.chimesdkmeetings.model.TranscribeLanguageCode.UNKNOWN_TO_SDK_VERSION
  }
  case object `en-US`
      extends zio.aws.chimesdkmeetings.model.TranscribeLanguageCode {
    override def unwrap
        : software.amazon.awssdk.services.chimesdkmeetings.model.TranscribeLanguageCode =
      software.amazon.awssdk.services.chimesdkmeetings.model.TranscribeLanguageCode.EN_US
  }
  case object `en-GB`
      extends zio.aws.chimesdkmeetings.model.TranscribeLanguageCode {
    override def unwrap
        : software.amazon.awssdk.services.chimesdkmeetings.model.TranscribeLanguageCode =
      software.amazon.awssdk.services.chimesdkmeetings.model.TranscribeLanguageCode.EN_GB
  }
  case object `es-US`
      extends zio.aws.chimesdkmeetings.model.TranscribeLanguageCode {
    override def unwrap
        : software.amazon.awssdk.services.chimesdkmeetings.model.TranscribeLanguageCode =
      software.amazon.awssdk.services.chimesdkmeetings.model.TranscribeLanguageCode.ES_US
  }
  case object `fr-CA`
      extends zio.aws.chimesdkmeetings.model.TranscribeLanguageCode {
    override def unwrap
        : software.amazon.awssdk.services.chimesdkmeetings.model.TranscribeLanguageCode =
      software.amazon.awssdk.services.chimesdkmeetings.model.TranscribeLanguageCode.FR_CA
  }
  case object `fr-FR`
      extends zio.aws.chimesdkmeetings.model.TranscribeLanguageCode {
    override def unwrap
        : software.amazon.awssdk.services.chimesdkmeetings.model.TranscribeLanguageCode =
      software.amazon.awssdk.services.chimesdkmeetings.model.TranscribeLanguageCode.FR_FR
  }
  case object `en-AU`
      extends zio.aws.chimesdkmeetings.model.TranscribeLanguageCode {
    override def unwrap
        : software.amazon.awssdk.services.chimesdkmeetings.model.TranscribeLanguageCode =
      software.amazon.awssdk.services.chimesdkmeetings.model.TranscribeLanguageCode.EN_AU
  }
  case object `it-IT`
      extends zio.aws.chimesdkmeetings.model.TranscribeLanguageCode {
    override def unwrap
        : software.amazon.awssdk.services.chimesdkmeetings.model.TranscribeLanguageCode =
      software.amazon.awssdk.services.chimesdkmeetings.model.TranscribeLanguageCode.IT_IT
  }
  case object `de-DE`
      extends zio.aws.chimesdkmeetings.model.TranscribeLanguageCode {
    override def unwrap
        : software.amazon.awssdk.services.chimesdkmeetings.model.TranscribeLanguageCode =
      software.amazon.awssdk.services.chimesdkmeetings.model.TranscribeLanguageCode.DE_DE
  }
  case object `pt-BR`
      extends zio.aws.chimesdkmeetings.model.TranscribeLanguageCode {
    override def unwrap
        : software.amazon.awssdk.services.chimesdkmeetings.model.TranscribeLanguageCode =
      software.amazon.awssdk.services.chimesdkmeetings.model.TranscribeLanguageCode.PT_BR
  }
  case object `ja-JP`
      extends zio.aws.chimesdkmeetings.model.TranscribeLanguageCode {
    override def unwrap
        : software.amazon.awssdk.services.chimesdkmeetings.model.TranscribeLanguageCode =
      software.amazon.awssdk.services.chimesdkmeetings.model.TranscribeLanguageCode.JA_JP
  }
  case object `ko-KR`
      extends zio.aws.chimesdkmeetings.model.TranscribeLanguageCode {
    override def unwrap
        : software.amazon.awssdk.services.chimesdkmeetings.model.TranscribeLanguageCode =
      software.amazon.awssdk.services.chimesdkmeetings.model.TranscribeLanguageCode.KO_KR
  }
  case object `zh-CN`
      extends zio.aws.chimesdkmeetings.model.TranscribeLanguageCode {
    override def unwrap
        : software.amazon.awssdk.services.chimesdkmeetings.model.TranscribeLanguageCode =
      software.amazon.awssdk.services.chimesdkmeetings.model.TranscribeLanguageCode.ZH_CN
  }
  case object `th-TH`
      extends zio.aws.chimesdkmeetings.model.TranscribeLanguageCode {
    override def unwrap
        : software.amazon.awssdk.services.chimesdkmeetings.model.TranscribeLanguageCode =
      software.amazon.awssdk.services.chimesdkmeetings.model.TranscribeLanguageCode.TH_TH
  }
  case object `hi-IN`
      extends zio.aws.chimesdkmeetings.model.TranscribeLanguageCode {
    override def unwrap
        : software.amazon.awssdk.services.chimesdkmeetings.model.TranscribeLanguageCode =
      software.amazon.awssdk.services.chimesdkmeetings.model.TranscribeLanguageCode.HI_IN
  }
}
